import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';


const csvUrl = 'https://gist.githubusercontent.com/harika-1929/b09d380322762cfba1d28ed1ce41db1c/raw/ccc3750127d552f182fb554420eb464d6e5a6039/colour';
const parseRow = (d) => {
  d.length_of_stand = +d.length_of_stand;
  d.width_of_stand = +d.width_of_stand;
  d.length_of_flag = +d.length_of_flag;
  d.width_of_flag = +d.width_of_flag;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.length_of_flag;
const yValue = (d) => d.width_of_flag;
const rxValue = (d) => d.length_of_stand;
const ryValue = (d) => d.width_of_stand;
const speciesValue = (d) => d.color;
const colorValue = d => d.color;
const colorLabel = 'Color';


const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.length_of_stand);
  const y = yValue((d) => d.width_of_flag);
  const marker = (d) => {
        	switch(d){
            case 'red':
              return 'red';
            case 'blue':
              return 'blue';
            default:
              return 'green';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.width_of_flag),
          y: yValue((d) => d.length_of_sepal),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//Defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.width_of_flag)
    .yValue((d) => d.length_of_stand)
    .margin({
      top: 35,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);





//Defining the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

     
    
  
  const columns = [
    'width_of_flag',
    'width_of_stand',
    'length_of_flag',
    'length_of_stand',
  ];

  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  /* Generates  'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length'*/
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","black")
          .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("Color Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

   
// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("red").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("green").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("blue").style("font-size", "20px").attr("alignment-baseline","middle")
  
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("Length of stand");
    
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "red")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "green")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "blue")
   // plot petal_width on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Width of flag");
     // plot sepal_width on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Width of stand");
     // plot petal_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Length of flag");
     // plot length_of_stand on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Length of stand");
    i++;
  }, 2000);// every 2 seconds change the visualization
};
main();



